"use strict";

import React, { useState, useMemo } from 'react';
import { Card, CardContent, CardHeader, CardTitle } from "./ui/card.js";
import { LineChart, Line, XAxis, YAxis, CartesianGrid, Tooltip, Legend, ResponsiveContainer, ReferenceDot } from 'recharts';
import { calculateDifferences, calculateStats } from "../App.utility.js";
import FallbackPage from "./FallbackPage.js";
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
const CustomTooltip = ({
  active,
  payload,
  label
}) => {
  if (active && payload && payload.length) {
    const data = payload[0].payload;
    return /*#__PURE__*/_jsxs("div", {
      className: "bg-white p-4 border border-gray-200 rounded shadow",
      children: [/*#__PURE__*/_jsxs("p", {
        className: "font-bold",
        children: ["Iteration ", label]
      }), /*#__PURE__*/_jsxs("p", {
        children: ["Start Marker: ", data.startMarker]
      }), /*#__PURE__*/_jsxs("p", {
        children: ["End Marker: ", data.endMarker]
      }), /*#__PURE__*/_jsxs("p", {
        children: ["Duration: ", data.duration.toFixed(2), " ms"]
      })]
    });
  }
  return null;
};
const PerformanceVisualization = ({
  startMarker,
  endMarker,
  data: rawData
}) => {
  const [selectedPoint, setSelectedPoint] = useState(null);
  const data = calculateDifferences(rawData, startMarker, endMarker);
  const {
    mean,
    standardDeviation,
    errorRate
  } = useMemo(() => calculateStats(data), [data]);
  const handleClick = point => {
    if (point && point.activePayload && point.activePayload.length > 0) {
      const index = data.findIndex(item => item.iteration === point.activePayload[0].payload.iteration);
      setSelectedPoint(index);
    }
  };
  if (data.length === 0) {
    return /*#__PURE__*/_jsx(FallbackPage, {
      startMarker: startMarker,
      endMarker: endMarker
    });
  }
  return /*#__PURE__*/_jsxs("div", {
    className: "w-full max-w-4xl space-y-8",
    children: [/*#__PURE__*/_jsxs("div", {
      className: "grid grid-cols-1 md:grid-cols-3 gap-4",
      children: [/*#__PURE__*/_jsxs(Card, {
        className: "bg-blue-50",
        children: [/*#__PURE__*/_jsx(CardHeader, {
          children: /*#__PURE__*/_jsx(CardTitle, {
            className: "text-lg font-semibold text-blue-700",
            children: "Mean"
          })
        }), /*#__PURE__*/_jsx(CardContent, {
          children: /*#__PURE__*/_jsxs("p", {
            className: "text-2xl font-bold text-blue-900",
            children: [mean.toFixed(2), " ms"]
          })
        })]
      }), /*#__PURE__*/_jsxs(Card, {
        className: "bg-green-50",
        children: [/*#__PURE__*/_jsx(CardHeader, {
          children: /*#__PURE__*/_jsx(CardTitle, {
            className: "text-lg font-semibold text-green-700",
            children: "Standard Deviation"
          })
        }), /*#__PURE__*/_jsx(CardContent, {
          children: /*#__PURE__*/_jsxs("p", {
            className: "text-2xl font-bold text-green-900",
            children: [standardDeviation, " ms"]
          })
        })]
      }), /*#__PURE__*/_jsxs(Card, {
        className: "bg-red-50",
        children: [/*#__PURE__*/_jsx(CardHeader, {
          children: /*#__PURE__*/_jsx(CardTitle, {
            className: "text-lg font-semibold text-red-700",
            children: "Error Rate"
          })
        }), /*#__PURE__*/_jsx(CardContent, {
          children: /*#__PURE__*/_jsxs("p", {
            className: "text-2xl font-bold text-red-900",
            children: [errorRate, "%"]
          })
        })]
      })]
    }), /*#__PURE__*/_jsxs(Card, {
      children: [/*#__PURE__*/_jsx(CardHeader, {
        children: /*#__PURE__*/_jsx(CardTitle, {
          className: "text-2xl font-bold",
          children: "Performance Graph"
        })
      }), /*#__PURE__*/_jsx(CardContent, {
        children: /*#__PURE__*/_jsx("div", {
          className: "h-[300px]",
          children: /*#__PURE__*/_jsx(ResponsiveContainer, {
            width: "100%",
            height: "100%",
            children: /*#__PURE__*/_jsxs(LineChart, {
              data: data,
              margin: {
                top: 5,
                right: 30,
                left: 20,
                bottom: 5
              },
              onClick: handleClick,
              children: [/*#__PURE__*/_jsx(CartesianGrid, {
                strokeDasharray: "3 3"
              }), /*#__PURE__*/_jsx(XAxis, {
                dataKey: "iteration"
              }), /*#__PURE__*/_jsx(YAxis, {}), /*#__PURE__*/_jsx(Tooltip, {
                content: /*#__PURE__*/_jsx(CustomTooltip, {})
              }), /*#__PURE__*/_jsx(Legend, {}), /*#__PURE__*/_jsx(Line, {
                type: "monotone",
                dataKey: "duration",
                stroke: "#8884d8",
                name: "Iteration"
              }), selectedPoint !== null && data[selectedPoint] && /*#__PURE__*/_jsx(ReferenceDot, {
                x: data[selectedPoint]?.iteration,
                y: data[selectedPoint]?.duration,
                r: 5,
                fill: "#8884d8",
                stroke: "none"
              })]
            })
          })
        })
      })]
    }), /*#__PURE__*/_jsxs(Card, {
      children: [/*#__PURE__*/_jsx(CardHeader, {
        children: /*#__PURE__*/_jsxs(CardTitle, {
          className: "text-2xl font-bold",
          children: ["Results for ", startMarker, " & ", endMarker]
        })
      }), /*#__PURE__*/_jsx(CardContent, {
        children: /*#__PURE__*/_jsx("div", {
          className: "overflow-x-auto",
          children: /*#__PURE__*/_jsxs("table", {
            className: "w-full border-collapse",
            children: [/*#__PURE__*/_jsx("thead", {
              children: /*#__PURE__*/_jsxs("tr", {
                className: "bg-gray-100",
                children: [/*#__PURE__*/_jsx("th", {
                  className: "border-b border-gray-300 px-4 py-2 text-left font-semibold text-gray-700",
                  children: "Iteration"
                }), /*#__PURE__*/_jsx("th", {
                  className: "border-b border-gray-300 px-4 py-2 text-left font-semibold text-gray-700",
                  children: "Start Marker"
                }), /*#__PURE__*/_jsx("th", {
                  className: "border-b border-gray-300 px-4 py-2 text-left font-semibold text-gray-700",
                  children: "End Marker"
                }), /*#__PURE__*/_jsx("th", {
                  className: "border-b border-gray-300 px-4 py-2 text-left font-semibold text-gray-700",
                  children: "Duration (ms)"
                })]
              })
            }), /*#__PURE__*/_jsx("tbody", {
              children: data.map(item => /*#__PURE__*/_jsxs("tr", {
                className: "hover:bg-gray-50",
                children: [/*#__PURE__*/_jsx("td", {
                  className: "border-b border-gray-300 px-4 py-2",
                  children: item.iteration
                }), /*#__PURE__*/_jsx("td", {
                  className: "border-b border-gray-300 px-4 py-2",
                  children: item.startMarker
                }), /*#__PURE__*/_jsx("td", {
                  className: "border-b border-gray-300 px-4 py-2",
                  children: item.endMarker
                }), /*#__PURE__*/_jsx("td", {
                  className: "border-b border-gray-300 px-4 py-2",
                  children: item.duration.toFixed(2)
                })]
              }, item.iteration))
            })]
          })
        })
      })]
    })]
  });
};
export default PerformanceVisualization;
//# sourceMappingURL=PerformanceVisualization.js.map